(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     55062,       1272]
NotebookOptionsPosition[     53365,       1239]
NotebookOutlinePosition[     53738,       1255]
CellTagsIndexPosition[     53695,       1252]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"LEF", "=", 
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0.1"}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Linewidth", " ", "enhancement", " ", "factor"}], "*)"}], 
   "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"LEF", "=", "1.9"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Linewidth", " ", "enhancement", " ", "factor"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GVD", "=", 
    RowBox[{
     RowBox[{"-", "1800"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"(", "1*^-15", ")"}], "^", "2"}], "/", 
      RowBox[{"(", "1*^-3", ")"}]}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Group", " ", "velocity", " ", 
    RowBox[{"dispersion", "[", 
     RowBox[{
      RowBox[{"s", "^", "2"}], "/", "m"}], "]"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"beta", "=", "0*^-12"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Kerr", " ", 
    RowBox[{"coefficient", "[", 
     RowBox[{"m", "/", 
      RowBox[{"V", "^", "2"}]}], "]"}]}], "*)"}], "\n", "\[IndentingNewLine]", 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"%%", " ", "Constants"}], "*)"}], "Subsection"], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"hbar", "=", "1.055*^-34"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Reduced", " ", 
    RowBox[{"Planck", "'"}], "s", " ", 
    RowBox[{"constant", "[", 
     RowBox[{"J", "*", "s"}], "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"elec", "=", "1.602*^-19"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Electron", " ", 
    RowBox[{"charge", "[", "C", "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "=", "3*^8"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Light", " ", 
    RowBox[{"speed", "[", 
     RowBox[{"m", "/", "s"}], "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eps0", "=", "8.85*^-12"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Vacuum", " ", 
    RowBox[{"permittivity", "[", 
     RowBox[{"F", "/", "m"}], "]"}]}], "*)"}], "\n", "\n", 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"%%", " ", "Parameters"}], "*)"}], "Subsection"], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mu", "=", 
    RowBox[{"1*^-9", "*", "elec"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Dipole", " ", "matrix", " ", 
    RowBox[{"element", "[", 
     RowBox[{"m", "*", "C"}], "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Tul", "=", "1*^-12"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Upper", "-", 
    RowBox[{"lower", " ", "transition", " ", 
     RowBox[{"time", "[", "s", "]"}]}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Tug", "=", "6*^-12"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Upper", "-", 
    RowBox[{"ground", " ", "transition", " ", 
     RowBox[{"time", "[", "s", "]"}]}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"T1", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1", "/", "Tul"}], "+", 
       RowBox[{"1", "/", "Tug"}]}], ")"}], "^", 
     RowBox[{"-", "1.0"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Gain", " ", "recovery", " ", 
    RowBox[{"time", "[", "s", "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"T2", "=", "60*^-15"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Dephasing", " ", 
    RowBox[{"time", "[", "s", "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"G", "=", "1"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Confinement", " ", "factor"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"lambda0", "=", "8*^-6"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Central", " ", 
    RowBox[{"wavelength", "[", "m", "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"w0", "=", 
    RowBox[{"2", "*", "Pi", "*", 
     RowBox[{"c", "/", "lambda0"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Central", " ", 
    RowBox[{"frequency", "[", "Hz", "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"J", "=", 
    RowBox[{
     RowBox[{"1.5*^3", "/", 
      RowBox[{
       RowBox[{"(", "1*^-2", ")"}], "^", "2"}]}], "/", "elec"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "Current", " ", "density", " ", "normalized", " ", "to", " ", "electron", 
    " ", 
    RowBox[{"charge", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"m", "^", "2"}]}], "*", 
      RowBox[{"1", "/", "s"}]}], "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "3.3"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Refractive", " ", "index"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"L", "=", "580*^-10"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "Period", " ", "length", " ", "or", " ", "thickness", " ", "of", " ", 
    "the", " ", "doped", " ", 
    RowBox[{"(", "active", ")"}], " ", 
    RowBox[{"region", "[", "m", "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"k2", "=", "GVD"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Dispersion", " ", "coefficient"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Esat", "=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"2", "*", 
      RowBox[{
       RowBox[{"hbar", "^", "2"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"mu", "^", "2"}], "*", "T1", "*", "T2"}], ")"}]}]}], "]"}]}],
    ";"}], 
  RowBox[{"(*", 
   RowBox[{"Saturation", " ", 
    RowBox[{"field", "[", 
     RowBox[{"V", "/", "m"}], "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"g0", "=", 
    RowBox[{"G", "*", 
     RowBox[{"mu", "^", "2"}], "*", "w0", "*", "T1", "*", "T2", "*", 
     RowBox[{"J", "/", 
      RowBox[{"(", 
       RowBox[{"hbar", "*", "n", "*", "c", "*", "eps0", "*", "L"}], 
       ")"}]}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Unsaturated", " ", 
    RowBox[{"gain", "[", "m", "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"aw", "=", 
    RowBox[{"4", "/", 
     RowBox[{"(", "1*^-2", ")"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Waveguide", " ", "power", " ", 
    RowBox[{"losses", "[", 
     RowBox[{"1", "/", "m"}], "]"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xi", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"LEF", "^", "2"}], "+", "1"}], "]"}], "-", "1"}], ")"}], "/", 
    "LEF"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a1", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"LEF", "*", "xi"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"xi", "^", "2"}]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a2", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"LEF", "-", "xi"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"xi", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3", " ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"xi", "^", "2"}]}], ")"}], "/", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"xi", "^", "2"}]}], ")"}], "^", "2"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4", " ", "=", 
   RowBox[{
    RowBox[{"-", "2"}], "*", 
    RowBox[{"xi", "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"xi", "^", "2"}]}], ")"}], "^", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a5", " ", "=", " ", 
   RowBox[{
    RowBox[{"a1", "*", "a3"}], "-", 
    RowBox[{"a2", "*", "a4"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a6", " ", "=", " ", 
   RowBox[{
    RowBox[{"a1", "*", "a4"}], "+", 
    RowBox[{"a2", "*", "a3"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g0LEF", " ", "=", " ", 
   RowBox[{"g0", "*", "a1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g1", " ", "=", " ", 
   RowBox[{
    RowBox[{"1", "/", "a1"}], "*", 
    RowBox[{"aw", "/", "g0LEF"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "*", "g0LEF"}], "-", "aw"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g2", " ", "=", " ", 
    RowBox[{
     RowBox[{"1", "/", "a1"}], "*", 
     RowBox[{
      RowBox[{"aw", "^", "2"}], "/", "g0LEF"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1valapprox", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "LEF"}], "/", "2"}], " ", "+", " ", 
    RowBox[{"k2", "*", 
     RowBox[{"g0", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", "g0"}], "-", "aw"}], ")"}], "*", "aw", "*", 
        RowBox[{"T2", "^", "2"}]}], ")"}]}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1val", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"g1", "*", "a6", "*", 
       RowBox[{"T2", "^", "2"}]}], " ", "+", " ", "k2"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"g1", "*", "a5", "*", 
      RowBox[{"T2", "^", "2"}]}], ")"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2valapprox", "=", 
   RowBox[{
    RowBox[{"LEF", "/", "2"}], "-", 
    RowBox[{"2", "*", "g0", "*", 
     RowBox[{"Esat", "^", "2"}], "*", 
     RowBox[{"beta", "/", 
      RowBox[{"(", 
       RowBox[{"aw", "^", "2"}], ")"}]}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"c2val", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"g2", "*", "a2"}], "-", 
     RowBox[{"2", "*", 
      RowBox[{"Esat", "^", "2"}], "*", "beta"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"g2", "*", "a1"}], ")"}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7758302693558054`*^9, 3.7758302693558054`*^9}, {
   3.7758303035472836`*^9, 3.775830445489815*^9}, {3.7758305432976313`*^9, 
   3.7758305459507685`*^9}, {3.7758306066821866`*^9, 
   3.7758306177982025`*^9}, {3.775830656809561*^9, 3.7758307266251855`*^9}, {
   3.7758310754524193`*^9, 3.7758310758100185`*^9}, {3.775831118864026*^9, 
   3.7758311219882317`*^9}, {3.7758311627011213`*^9, 
   3.7758311937041693`*^9}, {3.775832263563693*^9, 3.7758322641631827`*^9}, {
   3.7758327028772883`*^9, 3.7758327034416714`*^9}, 3.775832825076762*^9, 
   3.775833075513569*^9, {3.776713286325221*^9, 3.776713287263491*^9}, {
   3.7767134335659122`*^9, 3.7767134402412806`*^9}, {3.776713475302146*^9, 
   3.776713922520947*^9}, {3.7767140757051744`*^9, 3.7767140759919558`*^9}, {
   3.776714124762869*^9, 3.776714128637969*^9}, {3.7767141792001085`*^9, 
   3.7767142108605986`*^9}, {3.7767142511130323`*^9, 
   3.7767142613726535`*^9}, {3.7767142996975317`*^9, 3.776714300877765*^9}, {
   3.77671434342492*^9, 3.776714379842063*^9}, {3.7767144806453047`*^9, 
   3.7767144809890804`*^9}, {3.776714552166854*^9, 3.77671455240125*^9}, {
   3.776714625775226*^9, 3.7767146508581185`*^9}, {3.7767146983179*^9, 
   3.776714725853711*^9}, {3.7767147623699603`*^9, 3.776714817988346*^9}, {
   3.77671504126367*^9, 3.7767150451390324`*^9}, {3.776715604303028*^9, 
   3.776715612064561*^9}, {3.776769980382897*^9, 3.776769980986374*^9}, {
   3.776770048506171*^9, 3.776770118232689*^9}, {3.7767705363291707`*^9, 
   3.776770570555814*^9}, {3.776770601743868*^9, 3.7767706084164057`*^9}, 
   3.7767712686912103`*^9, 3.7767729971867867`*^9, {3.776773711450202*^9, 
   3.7767737147383676`*^9}, {3.7767737471314306`*^9, 3.776773784589963*^9}, 
   3.776773872984597*^9, {3.776773906513461*^9, 3.776773930149535*^9}, {
   3.776774109663169*^9, 3.776774110493353*^9}, {3.7767742278931627`*^9, 
   3.7767742455027685`*^9}, {3.7767815898359375`*^9, 
   3.7767816132264233`*^9}, {3.7767999649029846`*^9, 
   3.7767999884193573`*^9}, {3.77680005830158*^9, 3.7768000778130903`*^9}, 
   3.776800169311145*^9, {3.7768110211174436`*^9, 3.77681102466788*^9}, {
   3.777140289466199*^9, 3.777140298761969*^9}, {3.7796303299136505`*^9, 
   3.779630340196142*^9}, {3.7796316841752596`*^9, 3.7796316902173843`*^9}, {
   3.779723884484285*^9, 3.7797239175671616`*^9}, {3.7801576935554266`*^9, 
   3.780157701255421*^9}, 3.7801577936988745`*^9, {3.7801581251793413`*^9, 
   3.7801581706127477`*^9}, {3.780160486978805*^9, 3.780160487520709*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"05d2e455-6415-4bb6-83e5-d5f6223e4976"],

Cell[BoxData[
 RowBox[{"-", "1.939284577533403`"}]], "Output",
 CellChangeTimes->{{3.7767701020921926`*^9, 3.7767701189259567`*^9}, {
   3.7767705418871603`*^9, 3.776770571477682*^9}, 3.776770608947791*^9, 
   3.776771269472657*^9, 3.776771417047278*^9, 3.7767717872404113`*^9, 
   3.7767729978365254`*^9, {3.7767737290641546`*^9, 3.7767737873994007`*^9}, 
   3.776773873476162*^9, {3.7767739071384487`*^9, 3.776773931584176*^9}, 
   3.776774186522781*^9, {3.7767742287556577`*^9, 3.7767742462237263`*^9}, 
   3.7767797684846153`*^9, {3.776781577497747*^9, 3.7767816153471346`*^9}, 
   3.776794389693731*^9, {3.776799966988993*^9, 3.776799990357065*^9}, {
   3.7768000604112716`*^9, 3.7768000818134565`*^9}, {3.77680015772898*^9, 
   3.776800171815745*^9}, 3.776811025671549*^9, {3.7771209409670753`*^9, 
   3.7771209492822247`*^9}, 3.7771402020539846`*^9, {3.777140291781378*^9, 
   3.7771403014280815`*^9}, 3.7796302749757633`*^9, 3.7796303410398836`*^9, 
   3.7796316501425467`*^9, 3.779631692941699*^9, 3.7796317252109623`*^9, 
   3.779723773181774*^9, 3.77972395234237*^9, 3.7801576069765844`*^9, {
   3.7801576941178885`*^9, 3.780157702127655*^9}, 3.780157794218267*^9, {
   3.7801581176231313`*^9, 3.7801581275942907`*^9}, {3.7801581583536005`*^9, 
   3.7801581726619844`*^9}, 3.780159121576887*^9, 3.7801604898660264`*^9, 
   3.780160793795429*^9, {3.7801632161490407`*^9, 3.7801632412354374`*^9}, {
   3.780257123847682*^9, 3.7802572277928133`*^9}, 3.7802573429220657`*^9, 
   3.792896634916645*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"32b69e4b-9264-4013-a093-c1a53a353f15"],

Cell[BoxData[
 RowBox[{"-", "1.717077342481782`"}]], "Output",
 CellChangeTimes->{{3.7767701020921926`*^9, 3.7767701189259567`*^9}, {
   3.7767705418871603`*^9, 3.776770571477682*^9}, 3.776770608947791*^9, 
   3.776771269472657*^9, 3.776771417047278*^9, 3.7767717872404113`*^9, 
   3.7767729978365254`*^9, {3.7767737290641546`*^9, 3.7767737873994007`*^9}, 
   3.776773873476162*^9, {3.7767739071384487`*^9, 3.776773931584176*^9}, 
   3.776774186522781*^9, {3.7767742287556577`*^9, 3.7767742462237263`*^9}, 
   3.7767797684846153`*^9, {3.776781577497747*^9, 3.7767816153471346`*^9}, 
   3.776794389693731*^9, {3.776799966988993*^9, 3.776799990357065*^9}, {
   3.7768000604112716`*^9, 3.7768000818134565`*^9}, {3.77680015772898*^9, 
   3.776800171815745*^9}, 3.776811025671549*^9, {3.7771209409670753`*^9, 
   3.7771209492822247`*^9}, 3.7771402020539846`*^9, {3.777140291781378*^9, 
   3.7771403014280815`*^9}, 3.7796302749757633`*^9, 3.7796303410398836`*^9, 
   3.7796316501425467`*^9, 3.779631692941699*^9, 3.7796317252109623`*^9, 
   3.779723773181774*^9, 3.77972395234237*^9, 3.7801576069765844`*^9, {
   3.7801576941178885`*^9, 3.780157702127655*^9}, 3.780157794218267*^9, {
   3.7801581176231313`*^9, 3.7801581275942907`*^9}, {3.7801581583536005`*^9, 
   3.7801581726619844`*^9}, 3.780159121576887*^9, 3.7801604898660264`*^9, 
   3.780160793795429*^9, {3.7801632161490407`*^9, 3.7801632412354374`*^9}, {
   3.780257123847682*^9, 3.7802572277928133`*^9}, 3.7802573429220657`*^9, 
   3.7928966349186487`*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"d402d654-b3e7-4f33-b925-f9f21e0d697c"],

Cell[BoxData["0.95`"], "Output",
 CellChangeTimes->{{3.7767701020921926`*^9, 3.7767701189259567`*^9}, {
   3.7767705418871603`*^9, 3.776770571477682*^9}, 3.776770608947791*^9, 
   3.776771269472657*^9, 3.776771417047278*^9, 3.7767717872404113`*^9, 
   3.7767729978365254`*^9, {3.7767737290641546`*^9, 3.7767737873994007`*^9}, 
   3.776773873476162*^9, {3.7767739071384487`*^9, 3.776773931584176*^9}, 
   3.776774186522781*^9, {3.7767742287556577`*^9, 3.7767742462237263`*^9}, 
   3.7767797684846153`*^9, {3.776781577497747*^9, 3.7767816153471346`*^9}, 
   3.776794389693731*^9, {3.776799966988993*^9, 3.776799990357065*^9}, {
   3.7768000604112716`*^9, 3.7768000818134565`*^9}, {3.77680015772898*^9, 
   3.776800171815745*^9}, 3.776811025671549*^9, {3.7771209409670753`*^9, 
   3.7771209492822247`*^9}, 3.7771402020539846`*^9, {3.777140291781378*^9, 
   3.7771403014280815`*^9}, 3.7796302749757633`*^9, 3.7796303410398836`*^9, 
   3.7796316501425467`*^9, 3.779631692941699*^9, 3.7796317252109623`*^9, 
   3.779723773181774*^9, 3.77972395234237*^9, 3.7801576069765844`*^9, {
   3.7801576941178885`*^9, 3.780157702127655*^9}, 3.780157794218267*^9, {
   3.7801581176231313`*^9, 3.7801581275942907`*^9}, {3.7801581583536005`*^9, 
   3.7801581726619844`*^9}, 3.780159121576887*^9, 3.7801604898660264`*^9, 
   3.780160793795429*^9, {3.7801632161490407`*^9, 3.7801632412354374`*^9}, {
   3.780257123847682*^9, 3.7802572277928133`*^9}, 3.7802573429220657`*^9, 
   3.7928966349226456`*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"75d49c77-c1c9-48e1-8b5e-032d5c6d8245"],

Cell[BoxData["0.6037321343991523`"], "Output",
 CellChangeTimes->{{3.7767701020921926`*^9, 3.7767701189259567`*^9}, {
   3.7767705418871603`*^9, 3.776770571477682*^9}, 3.776770608947791*^9, 
   3.776771269472657*^9, 3.776771417047278*^9, 3.7767717872404113`*^9, 
   3.7767729978365254`*^9, {3.7767737290641546`*^9, 3.7767737873994007`*^9}, 
   3.776773873476162*^9, {3.7767739071384487`*^9, 3.776773931584176*^9}, 
   3.776774186522781*^9, {3.7767742287556577`*^9, 3.7767742462237263`*^9}, 
   3.7767797684846153`*^9, {3.776781577497747*^9, 3.7767816153471346`*^9}, 
   3.776794389693731*^9, {3.776799966988993*^9, 3.776799990357065*^9}, {
   3.7768000604112716`*^9, 3.7768000818134565`*^9}, {3.77680015772898*^9, 
   3.776800171815745*^9}, 3.776811025671549*^9, {3.7771209409670753`*^9, 
   3.7771209492822247`*^9}, 3.7771402020539846`*^9, {3.777140291781378*^9, 
   3.7771403014280815`*^9}, 3.7796302749757633`*^9, 3.7796303410398836`*^9, 
   3.7796316501425467`*^9, 3.779631692941699*^9, 3.7796317252109623`*^9, 
   3.779723773181774*^9, 3.77972395234237*^9, 3.7801576069765844`*^9, {
   3.7801576941178885`*^9, 3.780157702127655*^9}, 3.780157794218267*^9, {
   3.7801581176231313`*^9, 3.7801581275942907`*^9}, {3.7801581583536005`*^9, 
   3.7801581726619844`*^9}, 3.780159121576887*^9, 3.7801604898660264`*^9, 
   3.780160793795429*^9, {3.7801632161490407`*^9, 3.7801632412354374`*^9}, {
   3.780257123847682*^9, 3.7802572277928133`*^9}, 3.7802573429220657`*^9, 
   3.792896634924646*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"888c2e6d-bd98-45df-b910-27bbb46b99d4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c1dataapprox", " ", "=", "  ", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"LEF", ",", "c1valapprox"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1dataexact", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"LEF", ",", "c1val"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c1dataapprox", ",", " ", "c1dataexact"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<LEF\>\"", ",", "\"\<c1\>\""}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2dataapprox", " ", "=", "  ", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"LEF", ",", "c2valapprox"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2dataexact", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"LEF", ",", "c2val"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"c2dataapprox", ",", " ", "c2dataexact"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<LEF\>\"", ",", "\"\<c2\>\""}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7767150707437*^9, 3.776715177062153*^9}, {
   3.7767152138129396`*^9, 3.7767152268023977`*^9}, {3.7767152867387886`*^9, 
   3.7767154052216063`*^9}, {3.7767154416736975`*^9, 3.77671557558305*^9}, {
   3.7767717823646126`*^9, 3.7767717831773596`*^9}, 3.776773876600586*^9, {
   3.779630279600227*^9, 3.779630300046979*^9}, {3.7796303508732057`*^9, 
   3.77963035159204*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"0bdffce9-9b1a-4048-a914-311724b997d0"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{1.9, -1.939284577533403}, {1.9, -1.717077342481782}}]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"LEF\"", TraditionalForm], 
    FormBox["\"c1\"", TraditionalForm]},
  AxesOrigin->{0, -1.7047324960900256`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3.8}, {-1.939284577533403, -1.717077342481782}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.779630352154502*^9, 3.7796316502050548`*^9, 3.779631692997769*^9, 
   3.779631725265106*^9, 3.779723773805565*^9, 3.779723952479954*^9, 
   3.7801576076541586`*^9, {3.7801581176700478`*^9, 3.7801581276411705`*^9}, {
   3.7801581584161034`*^9, 3.780158172724492*^9}, 3.7801591216237936`*^9, 
   3.7801604899181557`*^9, 3.780160793850574*^9, {3.780163216191265*^9, 
   3.7801632412958717`*^9}, {3.780257124458439*^9, 3.780257227839692*^9}, 
   3.7802573429690695`*^9, 3.792896635360649*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"5f7e91fc-07d2-4aa4-819a-d85fcee3c2d3"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{1.9, 0.95}, {1.9, 0.6037321343991523}}]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"LEF\"", TraditionalForm], 
    FormBox["\"c2\"", TraditionalForm]},
  AxesOrigin->{0, 0.584495030754661},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3.8}, {0.584495030754661, 0.95}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.779630352154502*^9, 3.7796316502050548`*^9, 3.779631692997769*^9, 
   3.779631725265106*^9, 3.779723773805565*^9, 3.779723952479954*^9, 
   3.7801576076541586`*^9, {3.7801581176700478`*^9, 3.7801581276411705`*^9}, {
   3.7801581584161034`*^9, 3.780158172724492*^9}, 3.7801591216237936`*^9, 
   3.7801604899181557`*^9, 3.780160793850574*^9, {3.780163216191265*^9, 
   3.7801632412958717`*^9}, {3.780257124458439*^9, 3.780257227839692*^9}, 
   3.7802573429690695`*^9, 3.7928966353916807`*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"372c1563-7367-49d6-99af-7826ffb4a716"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"%%", " ", "Uncertainties"}], "*)"}], "Subsection"], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]T2", " ", "=", " ", "10*^-15"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]J", " ", "=", " ", 
     RowBox[{
      RowBox[{"0.1*^3", "/", 
       RowBox[{
        RowBox[{"(", "1*^-2", ")"}], "^", "2"}]}], "/", "elec"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]GVD", " ", "=", " ", 
     RowBox[{"360", "*", 
      RowBox[{
       RowBox[{
        RowBox[{"(", "1*^-15", ")"}], "^", "2"}], "/", 
       RowBox[{"(", "1*^-3", ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]aw", " ", "=", " ", 
     RowBox[{"1", "/", 
      RowBox[{"(", "1*^-2", ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]LEF", " ", "=", " ", "0.5"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]beta", " ", "=", " ", "2.5*^-12"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0var", "=", " ", 
     RowBox[{"(", 
      RowBox[{"G", "*", 
       RowBox[{"mu", "^", "2"}], "*", "w0", "*", "T1", "*", "T2var", "*", 
       RowBox[{"Jvar", "/", 
        RowBox[{"(", 
         RowBox[{"hbar", "*", "n", "*", "c", "*", "eps0", "*", "L"}], 
         ")"}]}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xivar", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"LEFvar", "^", "2"}], "+", "1"}], "]"}], "-", "1"}], ")"}], 
      "/", "LEFvar"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a1var", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"LEFvar", "*", "xivar"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"xivar", "^", "2"}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"a2var", "  ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"LEFvar", "-", "xivar"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"xivar", "^", "2"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a3var", "  ", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"xivar", "^", "2"}]}], ")"}], "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"xivar", "^", "2"}]}], ")"}], "^", "2"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a4var", "  ", "=", 
     RowBox[{
      RowBox[{"-", "2"}], "*", 
      RowBox[{"xivar", "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"xivar", "^", "2"}]}], ")"}], "^", "2"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a5var", "  ", "=", " ", 
     RowBox[{
      RowBox[{"a1var", "*", "a3var"}], "-", 
      RowBox[{"a2var", "*", "a4var"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a6var", "  ", "=", " ", 
     RowBox[{
      RowBox[{"a1var", "*", "a4var"}], "+", 
      RowBox[{"a2var", "*", "a3var"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0LEFvar", "  ", "=", " ", 
     RowBox[{"g0var", "*", "a1var"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1var", "  ", "=", " ", 
     RowBox[{
      RowBox[{"1", "/", "a1var"}], "*", 
      RowBox[{"awvar", "/", "g0LEFvar"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", "g0LEFvar"}], "-", "awvar"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2var", "  ", "=", " ", 
     RowBox[{
      RowBox[{"1", "/", "a1var"}], "*", 
      RowBox[{
       RowBox[{"awvar", "^", "2"}], "/", "g0LEFvar"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c1", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"g1var", "*", "a6var", "*", 
         RowBox[{"T2var", "^", "2"}]}], " ", "+", " ", "GVDvar"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"g1var", "*", "a5var", "*", 
        RowBox[{"T2var", "^", "2"}]}], ")"}]}]}], ";"}], 
   StyleBox["\[IndentingNewLine]", "Subsection"], 
   RowBox[{
    RowBox[{"c2", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"g2var", "*", "a2var"}], "-", 
        RowBox[{"2", "*", 
         RowBox[{"Esat", "^", "2"}], "*", "betavar"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"g2var", "*", "a1var"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", 
     RowBox[{"%%", " ", "Error", " ", "propagation"}], "*)"}], "Subsection"], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]c1", " ", "=", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c1", ",", "T2var"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]T2", " ", "^", "2"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c1", ",", "Jvar"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]J", " ", "^", "2"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c1", ",", "GVDvar"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]GVD", " ", "^", "2"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c1", ",", "awvar"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]aw", " ", "^", "2"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c1", ",", "LEFvar"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]LEF", "^", "2"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]c1val", "=", 
     RowBox[{"\[Sigma]c1", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"T2var", "\[Rule]", "T2"}], ",", 
        RowBox[{"Jvar", "\[Rule]", "J"}], ",", 
        RowBox[{"GVDvar", "\[Rule]", "GVD"}], ",", 
        RowBox[{"awvar", "\[Rule]", "aw"}], ",", 
        RowBox[{"LEFvar", "\[Rule]", "LEF"}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]c2", " ", "=", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c2", ",", "LEFvar"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]LEF", "^", "2"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c2", ",", "awvar"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]aw", "^", "2"}]}], "  ", "+", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c2", ",", "T2var"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]T2", "^", "2"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c2", ",", "Jvar"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]J", "^", "2"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"c2", ",", "betavar"}], "]"}], "^", "2"}], "*", 
        RowBox[{"\[Sigma]beta", "^", "2"}]}]}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]c2val", "=", 
     RowBox[{"\[Sigma]c2", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"LEFvar", "\[Rule]", "LEF"}], ",", 
        RowBox[{"T2var", "\[Rule]", "T2"}], ",", 
        RowBox[{"Jvar", "\[Rule]", "J"}], ",", 
        RowBox[{"awvar", "\[Rule]", "aw"}], ",", 
        RowBox[{"betavar", "\[Rule]", "beta"}]}], "}"}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.775831038674992*^9, 3.7758310616592293`*^9}, {
   3.77583124070394*^9, 3.7758312733263555`*^9}, {3.7758313496904173`*^9, 
   3.7758314358245287`*^9}, {3.77583198329421*^9, 3.7758319936905813`*^9}, {
   3.7758320638572693`*^9, 3.7758322237214704`*^9}, {3.775832276555588*^9, 
   3.775832338639513*^9}, {3.7758325012628255`*^9, 3.7758325165108147`*^9}, {
   3.775832643502617*^9, 3.7758326638776417`*^9}, {3.7758327109370356`*^9, 
   3.775832718287736*^9}, {3.7767707800843954`*^9, 3.776770927717493*^9}, {
   3.776770959803952*^9, 3.77677097005508*^9}, {3.7767710230763173`*^9, 
   3.7767710618564844`*^9}, {3.776771151116953*^9, 3.776771159469926*^9}, {
   3.776771191821017*^9, 3.7767713102132244`*^9}, 3.776771444810638*^9, {
   3.7767717203624754`*^9, 3.776771765471009*^9}, {3.7767718067654514`*^9, 
   3.7767718139327116`*^9}, {3.7767720837054253`*^9, 
   3.7767721015644245`*^9}, {3.7767740941419125`*^9, 
   3.7767741061397796`*^9}, {3.776774139101983*^9, 3.7767741826853275`*^9}, {
   3.7767742128724265`*^9, 3.776774214716565*^9}, {3.779631647798628*^9, 
   3.7796316481892805`*^9}, {3.77963172308229*^9, 3.7796317232246933`*^9}, 
   3.7801590975287423`*^9, {3.7801632124634385`*^9, 3.7801632391442013`*^9}, {
   3.780257141695617*^9, 3.7802572257284155`*^9}, {3.7802573408750596`*^9, 
   3.7802573409531918`*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"b3f985eb-0cd5-4197-b3de-87027d0818d3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"%%", " ", 
       RowBox[{"Result", ":", " ", "c1"}]}], " ", "=", " ", "cD"}], ";", " ", 
     RowBox[{"c2", " ", "=", " ", "cNL"}]}], "*)"}], "Subsection"], 
  StyleBox["\[IndentingNewLine]", "Subsection"], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"StringForm", "[", 
    RowBox[{"\"\<c1 = `` +/- ``\>\"", ",", "c1val", ",", "\[Sigma]c1val"}], 
    "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{"StringForm", "[", 
    RowBox[{"\"\<c2 = `` +/- ``\>\"", ",", "c2val", ",", "\[Sigma]c2val"}], 
    "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"BFlines", " ", "=", " ", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "c1"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"c1", ",", 
         RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Needs", "[", "\"\<ErrorBarPlots`\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"exp", " ", "=", " ", 
     RowBox[{"ErrorListPlot", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"c1val", ",", "c2val"}], "}"}], ",", 
         RowBox[{"ErrorBar", "[", 
          RowBox[{"\[Sigma]c1val", ",", "\[Sigma]c2val"}], "]"}]}], "}"}], 
       "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"BFlines", ",", "exp"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.775832373213261*^9, 3.775832405669207*^9}, {
   3.775832485112951*^9, 3.775832625873001*^9}, {3.7758326697113485`*^9, 
   3.775832676056304*^9}, 3.775832719894926*^9, {3.7767158064917917`*^9, 
   3.7767158075544677`*^9}, {3.776771317118865*^9, 3.776771324606252*^9}, {
   3.776772153623975*^9, 3.776772419083325*^9}, {3.7767724527275376`*^9, 
   3.776772514260846*^9}, {3.7767725794134693`*^9, 3.776772635348536*^9}, {
   3.776772689765803*^9, 3.7767726945013037`*^9}, {3.776772734659358*^9, 
   3.7767729115219107`*^9}, {3.776773844772586*^9, 3.7767738643812203`*^9}, {
   3.7767815545215073`*^9, 3.7767815620251217`*^9}, {3.7771402768723087`*^9, 
   3.777140277099916*^9}, {3.792898052155123*^9, 
   3.7928980606661196`*^9}},ExpressionUUID->"cd1f728c-0fc0-4a8b-bb4a-\
8ee9142f2bef"],

Cell[BoxData[
 InterpretationBox["\<\"c1 = \\!\\(\\*RowBox[{\\\"-\\\", \
\\\"1.717077342481782`\\\"}]\\) +/- \
\\!\\(\\*RowBox[{\\\"0.5294284723445177`\\\"}]\\)\"\>",
  StringForm["c1 = `` +/- ``", -1.717077342481782, 0.5294284723445177],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7767713292787323`*^9, {3.7767714267971215`*^9, 3.7767714500661144`*^9}, 
   3.77677172987253*^9, {3.776771770956106*^9, 3.7767718163234706`*^9}, 
   3.7767721051755385`*^9, 3.776772151702841*^9, 3.7767722386155787`*^9, {
   3.7767723372235746`*^9, 3.7767723629755945`*^9}, {3.77677239365204*^9, 
   3.776772419652356*^9}, {3.776772457220476*^9, 3.7767725163082523`*^9}, {
   3.7767726149664874`*^9, 3.7767726356824217`*^9}, {3.7767726916838884`*^9, 
   3.776772694833206*^9}, {3.776772782563278*^9, 3.776772812896082*^9}, {
   3.776772854784232*^9, 3.77677290179329*^9}, 3.77677293712022*^9, 
   3.7767730079693794`*^9, {3.7767737389892416`*^9, 3.7767737627819643`*^9}, {
   3.776773853261064*^9, 3.776773882994484*^9}, {3.776773916335888*^9, 
   3.776773940559973*^9}, {3.776774192828335*^9, 3.776774252826971*^9}, 
   3.7767797735442576`*^9, {3.7767815626337833`*^9, 3.7767816154443893`*^9}, 
   3.7767944013782387`*^9, {3.7767999673796825`*^9, 3.7767999904507957`*^9}, {
   3.7768000605050244`*^9, 3.776800081891591*^9}, {3.776800157807132*^9, 
   3.7768001719050035`*^9}, 3.7768110337256737`*^9, {3.7771209418223395`*^9, 
   3.777120957191309*^9}, 3.7771402021733027`*^9, {3.777140277720587*^9, 
   3.777140301512298*^9}, 3.7796302757258453`*^9, 3.7796316930532727`*^9, 
   3.7796317253242817`*^9, 3.7797237738680763`*^9, 3.7797239525268598`*^9, 
   3.780157607732227*^9, {3.7801581177325497`*^9, 3.780158127703701*^9}, {
   3.7801581584629607`*^9, 3.780158172771388*^9}, 3.780159121686274*^9, 
   3.7801604899763117`*^9, 3.780160793907459*^9, {3.7801632162538013`*^9, 
   3.780163241342753*^9}, {3.7802571245053473`*^9, 3.780257227886574*^9}, 
   3.780257343031597*^9, 3.7928966354276457`*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"52b8bd51-f64b-468c-89b1-8e7072cef241"],

Cell[BoxData[
 InterpretationBox["\<\"c2 = \
\\!\\(\\*RowBox[{\\\"0.6037321343991523`\\\"}]\\) +/- \
\\!\\(\\*RowBox[{\\\"0.45648589703403636`\\\"}]\\)\"\>",
  StringForm["c2 = `` +/- ``", 0.6037321343991523, 0.45648589703403636`],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7767713292787323`*^9, {3.7767714267971215`*^9, 3.7767714500661144`*^9}, 
   3.77677172987253*^9, {3.776771770956106*^9, 3.7767718163234706`*^9}, 
   3.7767721051755385`*^9, 3.776772151702841*^9, 3.7767722386155787`*^9, {
   3.7767723372235746`*^9, 3.7767723629755945`*^9}, {3.77677239365204*^9, 
   3.776772419652356*^9}, {3.776772457220476*^9, 3.7767725163082523`*^9}, {
   3.7767726149664874`*^9, 3.7767726356824217`*^9}, {3.7767726916838884`*^9, 
   3.776772694833206*^9}, {3.776772782563278*^9, 3.776772812896082*^9}, {
   3.776772854784232*^9, 3.77677290179329*^9}, 3.77677293712022*^9, 
   3.7767730079693794`*^9, {3.7767737389892416`*^9, 3.7767737627819643`*^9}, {
   3.776773853261064*^9, 3.776773882994484*^9}, {3.776773916335888*^9, 
   3.776773940559973*^9}, {3.776774192828335*^9, 3.776774252826971*^9}, 
   3.7767797735442576`*^9, {3.7767815626337833`*^9, 3.7767816154443893`*^9}, 
   3.7767944013782387`*^9, {3.7767999673796825`*^9, 3.7767999904507957`*^9}, {
   3.7768000605050244`*^9, 3.776800081891591*^9}, {3.776800157807132*^9, 
   3.7768001719050035`*^9}, 3.7768110337256737`*^9, {3.7771209418223395`*^9, 
   3.777120957191309*^9}, 3.7771402021733027`*^9, {3.777140277720587*^9, 
   3.777140301512298*^9}, 3.7796302757258453`*^9, 3.7796316930532727`*^9, 
   3.7796317253242817`*^9, 3.7797237738680763`*^9, 3.7797239525268598`*^9, 
   3.780157607732227*^9, {3.7801581177325497`*^9, 3.780158127703701*^9}, {
   3.7801581584629607`*^9, 3.780158172771388*^9}, 3.780159121686274*^9, 
   3.7801604899763117`*^9, 3.780160793907459*^9, {3.7801632162538013`*^9, 
   3.780163241342753*^9}, {3.7802571245053473`*^9, 3.780257227886574*^9}, 
   3.780257343031597*^9, 3.792896635431647*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"c615aef7-0cad-4e57-9b17-bc0bfb04195f"],

Cell[BoxData[
 TemplateBox[{
  "General","obspkg",
   "\"\\!\\(\\*RowBox[{\\\"\\\\\\\"ErrorBarPlots`\\\\\\\"\\\"}]\\) is now \
obsolete. The legacy version being loaded may conflict with current \
functionality. See the Compatibility Guide for updating information.\"",2,70,
   1,18631422004324657401,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7928966356296463`*^9},
 CellLabel->
  "During evaluation of \
In[67]:=",ExpressionUUID->"fad05e81-e6c5-469b-b9e6-a19cce1ff3aa"],

Cell[BoxData[
 GraphicsBox[{{{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwVjHk81AkfgGcmN0mGShdKiXVESqG+U5K1tnjlaFekZDMIOUuuyms7veuq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         "]], LineBox[CompressedData["
1:eJwVi3s41HkfhpkdJgzJT5EOkkMOnROL8v2hid6lFdWWFaVR8lJRLIXdkJwW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         "]]},
       Annotation[#, 
        "Charting`Private`Tag$5882#1"]& ], {}}, {{}, {}}, {{}, {}}}, {}}, \
{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{{-1.717077342481782, 0.6037321343991523}, {-1.717077342481782,
        0.6037321343991523}}], {{
        LineBox[{{-1.1876488701372643`, 
         0.6037321343991523}, {-2.2465058148262997`, 0.6037321343991523}}], 
        LineBox[{
         Offset[{0, 1.5}, {-1.1876488701372643`, 0.6037321343991523}], 
          Offset[{0, -1.5}, {-1.1876488701372643`, 0.6037321343991523}]}], 
        LineBox[{
         Offset[{0, 1.5}, {-2.2465058148262997`, 0.6037321343991523}], 
          Offset[{0, -1.5}, {-2.2465058148262997`, 0.6037321343991523}]}], 
        LineBox[{{-1.717077342481782, 
         1.0602180314331886`}, {-1.717077342481782, 0.14724623736511594`}}], 
        LineBox[{
         Offset[{1.5, 0}, {-1.717077342481782, 1.0602180314331886`}], 
          Offset[{-1.5, 0}, {-1.717077342481782, 1.0602180314331886`}]}], 
        LineBox[{
         Offset[{1.5, 0}, {-1.717077342481782, 0.14724623736511594`}], 
          Offset[{-1.5, 0}, {-1.717077342481782, 0.14724623736511594`}]}]}, {
        LineBox[{{-1.1876488701372643`, 
         0.6037321343991523}, {-2.2465058148262997`, 0.6037321343991523}}], 
        LineBox[{
         Offset[{0, 1.5}, {-1.1876488701372643`, 0.6037321343991523}], 
          Offset[{0, -1.5}, {-1.1876488701372643`, 0.6037321343991523}]}], 
        LineBox[{
         Offset[{0, 1.5}, {-2.2465058148262997`, 0.6037321343991523}], 
          Offset[{0, -1.5}, {-2.2465058148262997`, 0.6037321343991523}]}], 
        LineBox[{{-1.717077342481782, 
         1.0602180314331886`}, {-1.717077342481782, 0.14724623736511594`}}], 
        LineBox[{
         Offset[{1.5, 0}, {-1.717077342481782, 1.0602180314331886`}], 
          Offset[{-1.5, 0}, {-1.717077342481782, 1.0602180314331886`}]}], 
        LineBox[{
         Offset[{1.5, 0}, {-1.717077342481782, 0.14724623736511594`}], 
          Offset[{-1.5, 0}, {-1.717077342481782, 0.14724623736511594`}]}]}}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-5, 5}, {-2.283456624851149, 2.2809464114575815`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7767713292787323`*^9, {3.7767714267971215`*^9, 3.7767714500661144`*^9}, 
   3.77677172987253*^9, {3.776771770956106*^9, 3.7767718163234706`*^9}, 
   3.7767721051755385`*^9, 3.776772151702841*^9, 3.7767722386155787`*^9, {
   3.7767723372235746`*^9, 3.7767723629755945`*^9}, {3.77677239365204*^9, 
   3.776772419652356*^9}, {3.776772457220476*^9, 3.7767725163082523`*^9}, {
   3.7767726149664874`*^9, 3.7767726356824217`*^9}, {3.7767726916838884`*^9, 
   3.776772694833206*^9}, {3.776772782563278*^9, 3.776772812896082*^9}, {
   3.776772854784232*^9, 3.77677290179329*^9}, 3.77677293712022*^9, 
   3.7767730079693794`*^9, {3.7767737389892416`*^9, 3.7767737627819643`*^9}, {
   3.776773853261064*^9, 3.776773882994484*^9}, {3.776773916335888*^9, 
   3.776773940559973*^9}, {3.776774192828335*^9, 3.776774252826971*^9}, 
   3.7767797735442576`*^9, {3.7767815626337833`*^9, 3.7767816154443893`*^9}, 
   3.7767944013782387`*^9, {3.7767999673796825`*^9, 3.7767999904507957`*^9}, {
   3.7768000605050244`*^9, 3.776800081891591*^9}, {3.776800157807132*^9, 
   3.7768001719050035`*^9}, 3.7768110337256737`*^9, {3.7771209418223395`*^9, 
   3.777120957191309*^9}, 3.7771402021733027`*^9, {3.777140277720587*^9, 
   3.777140301512298*^9}, 3.7796302757258453`*^9, 3.7796316930532727`*^9, 
   3.7796317253242817`*^9, 3.7797237738680763`*^9, 3.7797239525268598`*^9, 
   3.780157607732227*^9, {3.7801581177325497`*^9, 3.780158127703701*^9}, {
   3.7801581584629607`*^9, 3.780158172771388*^9}, 3.780159121686274*^9, 
   3.7801604899763117`*^9, 3.780160793907459*^9, {3.7801632162538013`*^9, 
   3.780163241342753*^9}, {3.7802571245053473`*^9, 3.780257227886574*^9}, 
   3.780257343031597*^9, 3.792896635741646*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"35f13e75-e25c-4440-ae67-44462ba984c6"]
}, Open  ]]
},
WindowSize->{1920, 997},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
Magnification:>1.2 Inherited,
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 12227, 362, 1198, "Input",ExpressionUUID->"05d2e455-6415-4bb6-83e5-d5f6223e4976"],
Cell[12810, 386, 1587, 22, 39, "Output",ExpressionUUID->"32b69e4b-9264-4013-a093-c1a53a353f15"],
Cell[14400, 410, 1589, 22, 39, "Output",ExpressionUUID->"d402d654-b3e7-4f33-b925-f9f21e0d697c"],
Cell[15992, 434, 1559, 21, 39, "Output",ExpressionUUID->"75d49c77-c1c9-48e1-8b5e-032d5c6d8245"],
Cell[17554, 457, 1571, 21, 39, "Output",ExpressionUUID->"888c2e6d-bd98-45df-b910-27bbb46b99d4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19162, 483, 1801, 47, 180, "Input",ExpressionUUID->"0bdffce9-9b1a-4048-a914-311724b997d0"],
Cell[20966, 532, 2118, 49, 279, "Output",ExpressionUUID->"5f7e91fc-07d2-4aa4-819a-d85fcee3c2d3"],
Cell[23087, 583, 2088, 49, 289, "Output",ExpressionUUID->"372c1563-7367-49d6-99af-7826ffb4a716"]
}, Open  ]],
Cell[25190, 635, 9127, 247, 744, "Input",ExpressionUUID->"b3f985eb-0cd5-4197-b3de-87027d0818d3"],
Cell[CellGroupData[{
Cell[34342, 886, 2326, 54, 233, "Input",ExpressionUUID->"cd1f728c-0fc0-4a8b-bb4a-8ee9142f2bef"],
Cell[36671, 942, 2071, 30, 39, "Output",ExpressionUUID->"52b8bd51-f64b-468c-89b1-8e7072cef241"],
Cell[38745, 974, 2062, 30, 39, "Output",ExpressionUUID->"c615aef7-0cad-4e57-9b17-bc0bfb04195f"],
Cell[40810, 1006, 500, 11, 27, "Message",ExpressionUUID->"fad05e81-e6c5-469b-b9e6-a19cce1ff3aa"],
Cell[41313, 1019, 12036, 217, 288, "Output",ExpressionUUID->"35f13e75-e25c-4440-ae67-44462ba984c6"]
}, Open  ]]
}
]
*)

